##  TIME Classification
The Gartner® TIME framework is a methodology used in Enterprise Architecture Management to assess an organization's application portfolio. TIME stands for Tolerate, Invest, Migrate, and Eliminate. It categorizes applications based on their strategic value and the effort required to manage them effectively. The TIME classification helps in assessing and prioritizing applications for rationalization and modernization initiatives.
In SAP LeanIX, the TIME classification for applications is based on the Functional and Technical Fit assessment of the applications. Using those assessments, each application is categorized under one of four quadrants:
  * Tolerate: Applications that don't provide the best business value but have an important function and high IT quality.
  * Invest: Applications valuable to the business and warrant future investment.
  * Migrate: Applications serving a business purpose in the IT landscape but creating problems, and therefore need to be migrated to improve function.
  * Eliminate: Applications that perform poorly and are no longer aligned with business activities.
